package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@$!`0````````````,`*``!````G!P``#0````@DP````0`!30`(``)
M`"@`'0`<``$``'",C0``C(T``(R-``#8````V`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!HC@``:(X```4```````$`
M`0```-B.``#8C@$`V(X!`-0"``#L$@``!@```````0`"````X(X``.".`0#@
MC@$`(`$``"`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DV(X`
M`-B.`0#8C@$`*`$``"@!```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50`<9<0ZCM<[=C`1,`S7MV>U$V5,>6$```!P````````````
M````````1P``````````````*P``````````````.P```#X`````````3@``
M`#T```!D`````````"X```!6````5P```#8```!F````;0````,````S````
M```````````D````00```$(``````````````!0```!-````.@```%(`````
M````;P```%L`````````40`````````;`````````$4```!G````50```#<`
M````````4````&D`````````#@```#\``````````````&`````U````3```
M`$H``````````````!``````````0P`````````````````````````8````
M+0```#````!$````(P```"@```````````````L```!+````/````$````!:
M````.0```#(```!N````1@```````````````````&H```!<`````````$@`
M``!>````*0````8````E````3P``````````````````````````````````
M````````````!```````````````:```````````````````````````````
M```````````2````6````%T`````````````````````````````````````
M````````````````````'@````````!K````90`````````@````````````
M```<`````````&P````'`````````!$`````````'0`````````/````(0``
M`"<````(````#0```!\````O``````````````!?````&@```%0`````````
M`````%D````F````8@```#$````6````+````!D````,``````````````!A
M````-````!4```!)````8P````````````````````D`````````````````
M````````!0```````````````````#@````B````````````````````$P``
M````````````*@```!<`````````````````````````````````````````
M``````H```!3```````````````1````4@````@````(`````9`0!"5`!(`H
M@``!H(90@(`!```+*`2-.*`218H$"`A2````4P```%<```!<````70```&0`
M``!E````9@```&@```!I`````````&L```!L````;0```&\`````````````
M``&O-.CJT^\.;L7?'\[>1RUK?YI\+L6;MM1DU'QV5#R4(/_D#KF-\0[9<5@<
MXD?&`;(!BV^L2^/`PN4_+%COEWFZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-
M%.*>,F+;[=O-XYX-.I<+?ZF<F^"G`@J_VE<;H^#[20``````````````````
M````````T!8````````#``P``````%"1`0```````P`8`%\"````````````
M`!(````'`0`````````````2````;0(`````````````$@```-@"````````
M`````!(```".```````````````2````_```````````````$0```(X!````
M`````````!(```!2`P`````````````2````H@,`````````````$@```!T!
M`````````````!(````,```````````````@````#@,`````````````$@``
M`$X!`````````````!(```"O```````````````2````/@$`````````````
M$@```)8"`````````````!(````P`0`````````````2````OP(`````````
M````$@```!L``````````````"````"L`0`````````````2````\0(`````
M````````$@````P!`````````````!(````0`@`````````````2````U@$`
M````````````$@```$0#`````````````!(````W```````````````@````
M`0,`````````````$@```%$``````````````!(```!^`0`````````````2
M````;@``````````````$@```.L``````````````!(```!_````````````
M```2````CP(`````````````$@```%@"`````````````!(```"X`@``````
M```````2````D`0`````````````$@```,\``````````````!(```!F`P``
M```````````1````\`$`````````````$@```((#`````````````!$```!P
M`0`````````````2````G0(`````````````$@```.H!`````````````!(`
M``!B`0`````````````2````/@(`````````````$@```.`"````````````
M`!(```"!`@`````````````2````$0$`````````````$@````@"````````
M`````!(```"E`0`````````````2````1P(`````````````$@```*H"````
M`````````!(```"(`@`````````````2````I`(`````````````$@```#P#
M`````````````!(````?`@`````````````2````90,`````````````(0``
M`)H``````````````!(```!Z`@`````````````2````F0$`````````````
M$@```/@"`````````````!(```!D`P`````````````1````Z@(`````````
M````$0```,T"`````````````!(```#>```````````````1````%0,`````
M````````$@```+<!`````````````!$````N`P`````````````2````-@(`
M````````````$@```%<!`````````````!(```!E`@`````````````2````
M7P``````````````$@```+D#`````````````!(```!S`@`````````````2
M````2P,`````````````$@```#$"`````````````!(```#W`0``````````
M```2````'P,`````````````(@```+T``````````````!(```#R`P``Q*$!
M```````0`!D`,@0``)Q,````````$@`/`)D$``!,2P``H````!(`#@#9!```
M0#P``,0*```2``X`7P,``/`9``"L`@``$@`.``H$``!@,P``!````!(`#@`X
M!```!$<``$@$```2``X`XP,``*R1`0``````$``9`/@$``!D,P``N`(``!(`
M#@##!```T!8````````2``P`UP,``*R1`0``````$``9`!L$```<-@``*```
M`!(`#@!.!````#H``*P````2``X`I00``*1,```$````$0`0`,$$``"4,0``
M7````!(`#@#]`P``Q*$!```````0`!D`!00``,2A`0``````$``9`.8$``#0
M.@``<`$``!(`#@"T!```4)$!```````0`!@`<@0``$0V``!0`0``$@`.`-`#
M``"LD0$``````!``&``%!0``J)$!``0````1`!@`*`0``)A,```$````$@`.
M`+H$``"<'````````!(`#@#)!```$$P``(@````2``X`M@0``%"1`0``````
M(``8`'X$``"L.@``)````!(`#@!<!```;#(``/0````2``X`\0,``,2A`0``
M````$``9``\%``"4-P``;`(``!(`#@``;&EB<&5R;"YS;P!?7V=M;VY?<W1A
M<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E
M<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E
M<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F
M;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T
M9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R
M;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`
M8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C
M`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`'!T
M:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I
M;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E
M>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`
M;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T
M;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M
M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A
M=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK`'-T<F-H
M<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM
M;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N
M`&QD+6QI;G5X+6%R;6AF+G-O+C,`7U]S=&%C:U]C:&M?9W5A<F0`;&EB9V-C
M7W,N<V\N,0!?7V%E86)I7W5N=VEN9%]C<'!?<'(P`%]?865A8FE?=6YW:6YD
M7V-P<%]P<C$`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`7U]B
M<W-?96YD7U\`7U]E;F1?7P!?96YD`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A
M<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`
M<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA
M;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/
M7W-T9&EN7W5S960`7U]D871A7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I
M;FET`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C0`1T-#7S,N-0`O
M=7-R+VQI8B]P97)L-2\U+C(V+C$O87)M=C=L+6QI;G5X+71H<F5A9"UM=6QT
M:2]#3U)%```````````"`````@`"``````````(``P```````@`````````"
M`````@```````@`"``0`!``"`````@```````````````@`"``(``@````(`
M!``%`````@`$`````@`"``(````$``(``@`"``(``@`"``(``@````(````"
M``(``@`"`````@````(``@````(````#``(``@`"``0``@````$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0!N`P``$````"`````4:6D-```%`!P%`````````0`!`,8!
M```0````(````!1I:0T```0`'`4````````!``$`E`,``!`````@````529Y
M"P```P`F!0````````$``0`5`@``$``````````4:6D-```"`!P%````````
MV(X!`!<```#<C@$`%P````R1`0`7````+)$!`!<````PD0$`%P```$R1`0`7
M````5)$!`!<```!<D0$`%P```&"1`0`7````9)$!`!<```!HD0$`%P```&R1
M`0`7````<)$!`!<```!XD0$`%P```'R1`0`7````A)$!`!<```"(D0$`%P``
M`(R1`0`7````D)$!`!<```"4D0$`%P```)R1`0`7````H)$!`!<```"HD0$`
M%P```!"1`0`5"```%)$!`!4,```8D0$`%0T``!R1`0`5%0``()$!`!4<```D
MD0$`%1\``"B1`0`5(```-)$!`!4H```XD0$`%2H``#R1`0`500``0)$!`!5#
M``!$D0$`%44``$B1`0`54```#)`!`!8#```0D`$`%@0``!20`0`6!0``&)`!
M`!8&```<D`$`%@<``""0`0`6"0``))`!`!8*```HD`$`%@T``"R0`0`6#@``
M,)`!`!8/```TD`$`%A```#B0`0`6$0``/)`!`!82``!`D`$`%A,``$20`0`6
M%```2)`!`!86``!,D`$`%A<``%"0`0`6&```5)`!`!89``!8D`$`%AH``%R0
M`0`6&P``8)`!`!8=``!DD`$`%AX``&B0`0`6(0``;)`!`!8B``!PD`$`%B,`
M`'20`0`6)```>)`!`!8E``!\D`$`%B8``("0`0`6)P``A)`!`!8I``"(D`$`
M%BL``(R0`0`6+```D)`!`!8M``"4D`$`%BX``)B0`0`6+P``G)`!`!8P``"@
MD`$`%C$``*20`0`6,@``J)`!`!8S``"LD`$`%C0``+"0`0`6-0``M)`!`!8V
M``"XD`$`%C<``+R0`0`6.```P)`!`!8Y``#$D`$`%CH``,B0`0`6/```S)`!
M`!8]``#0D`$`%CX``-20`0`6/P``V)`!`!9"``#<D`$`%D0``."0`0`61@``
MY)`!`!9'``#HD`$`%D@``.R0`0`620``\)`!`!9*``#TD`$`%DP``/B0`0`6
M30``_)`!`!9.````D0$`%D\```21`0`64```")$!`!91```(0"WIA@$`ZPB`
MO>@$X"WE!."?Y0[@C^`(\+[E%'D!``#&C^(7RHSB%/F\Y0#&C^(7RHSB#/F\
MY0#&C^(7RHSB!/F\Y0#&C^(7RHSB_/B\Y0#&C^(7RHSB]/B\Y0#&C^(7RHSB
M[/B\Y0#&C^(7RHSBY/B\Y0#&C^(7RHSBW/B\Y0#&C^(7RHSBU/B\Y0#&C^(7
MRHSBS/B\Y0#&C^(7RHSBQ/B\Y0#&C^(7RHSBO/B\Y0#&C^(7RHSBM/B\Y0#&
MC^(7RHSBK/B\Y0#&C^(7RHSBI/B\Y0#&C^(7RHSBG/B\Y0#&C^(7RHSBE/B\
MY0#&C^(7RHSBC/B\Y0#&C^(7RHSBA/B\Y0#&C^(7RHSB?/B\Y0#&C^(7RHSB
M=/B\Y0#&C^(7RHSB;/B\Y0#&C^(7RHSB9/B\Y0#&C^(7RHSB7/B\Y0#&C^(7
MRHSB5/B\Y0#&C^(7RHSB3/B\Y0#&C^(7RHSB1/B\Y0#&C^(7RHSB//B\Y0#&
MC^(7RHSB-/B\Y0#&C^(7RHSB+/B\Y0#&C^(7RHSB)/B\Y0#&C^(7RHSB'/B\
MY0#&C^(7RHSB%/B\Y0#&C^(7RHSB#/B\Y0#&C^(7RHSB!/B\Y0#&C^(7RHSB
M_/>\Y0#&C^(7RHSB]/>\Y0#&C^(7RHSB[/>\Y0#&C^(7RHSBY/>\Y0#&C^(7
MRHSBW/>\Y0#&C^(7RHSBU/>\Y0#&C^(7RHSBS/>\Y0#&C^(7RHSBQ/>\Y0#&
MC^(7RHSBO/>\Y0#&C^(7RHSBM/>\Y0#&C^(7RHSBK/>\Y0#&C^(7RHSBI/>\
MY0#&C^(7RHSBG/>\Y0#&C^(7RHSBE/>\Y0#&C^(7RHSBC/>\Y0#&C^(7RHSB
MA/>\Y0#&C^(7RHSB?/>\Y0#&C^(7RHSB=/>\Y0#&C^(7RHSB;/>\Y0#&C^(7
MRHSB9/>\Y0#&C^(7RHSB7/>\Y0#&C^(7RHSB5/>\Y0#&C^(7RHSB3/>\Y0#&
MC^(7RHSB1/>\Y0#&C^(7RHSB//>\Y0#&C^(7RHSB-/>\Y0#&C^(7RHSB+/>\
MY0#&C^(7RHSB)/>\Y0#&C^(7RHSB'/>\Y?1!;>%40I_E5#*?Y?A@S>$0X(WE
M)-!-X@1`C^`,((WE#""-XA`0C>40$(WB%`"-Y0-0E.<4`(WB`#"5Y1PPC>79
M___K'"*?Y1PRG^4"()3G`P"4YP(0H.%G#`#K##*?Y0,PE.<`<-/E``!7XU4`
M``K\,9_E`V"4YP``EN58___K[C/0Y0`@H.$``);E`C"#X^XSPN52___K%#"=
MY>XCT.4%,(/B`2""XP<!<^/N(\#E6@``B@,!H.$$0*#CHO__Z[`1G^40,)WE
MK.&?Y:S!G^4!$(_@%""=Y0!@D>6@$9_E#N"/X`!PD^4,P(_@`0!2XP$0C^"`
M0(#H"&"`Y0S`@.4$0('E"`"!Y08``-H"X8/@#!"`X@0P@^`$P)/D#@!3X03`
MH>7[__\:`!"@XPW!@N)009_E`#"@X0,@@N(`$(WE#!&`YT`1G^4$0(_@$`"4
MY0$0C^#X_O_K`&!0XBL```HH09_E&'"-X@1`C^`0`)3E2/__ZQ@!G^4'$*#A
M``"/X+`#`.L``%#C&P``"@0QG^4#,(_@$`"3Y=O^_^L9___K'""=Y08`H.$`
M,)7E`P!2X2<``!HDT(WBT$#-X=A@S>$0T(WB!/"=Y/G^_^O(,)_E``!0XP,P
MC^`0`(/E'0``"@[__^N(,)_E`V"4YP``EN7[_O_K57;`Y9[__^H,`)3E``!0
MXPH```K3"P#KWO__ZA``E.74_O_K`&"@X<___^IX,)_E>`"?Y0,0E.<``(_@
M/___ZVP`G^4'$*#A``"/X(`#`.L``%#C#`"$Y<[__PKL___J)/__ZP$`H.-;
M___K\'4!`#@!```4`0``*`$``$`!```0`0``X'8!`!`U```,-0``R'8!`'!V
M`0"H%@``4'8!`"PR```H=@$`Y'4!`$0!``#\,@``"#$```"PH.,`X*#C!!"=
MY`T@H.$$("WE!``MY2B@G^4D,(_B`Z"*X"#`G^4,P)KG!,`MY1@PG^4#,)KG
M%`"?Y0``FN>5_O_KB/[_ZQQS`0`,`0``,`$``$P!```4,)_E%""?Y0,PC^`"
M()/G``!2XQ[_+P&,_O_J_'(!`!@!```P`)_E,#"?Y3`@G^4``(_@`S"/X```
M4^$"((_@!```"APPG^4#,)+G``!3XP````H3_R_A'O\OX8!T`0!\=`$`R'(!
M`!P!```\`)_E/#"?Y3P@G^4``(_@`S"/X``00^`"((_@01&@X:$?@>#!$+#A
M!```"APPG^4#,)+G``!3XP````H3_R_A'O\OX3AT`0`T=`$`@'(!`"`!``!8
M,)_E6""?Y0,PC^``,-/E`B"/X```4^,>_R\11#"?Y0A`+>4$X(WE`S"2YP``
M4^,"```*,#"?Y0,`G^?X_O_KQ___ZR0PG^4!(*#C`$"=Y030C>(#,(_@`"##
MY03PG>3H<P$`-'(!`$@!``!@<P$`G',!`,S__^K\.Y_E]$)MX1P@@.+T2Y_E
M^&#-X5S`@.+P@<WA^*'-X0,PC^`@X(WE5=]-X@0PD^<(X(WB#A"@X00PC>4`
M,)/E3#&-Y00PDN0S/[_F`@!<X00PH>7Z__\:0D^-X@X@H.$$$+[E),"2Y3@P
MDN4,()+E!`!>X0PP(^`","/@`3`CX.,_H.%`,([E\___&@"`D.69&0?CH2L.
MX]1@P.&"&D7CV2Y&XPQ0D.7</`OC$."=Y1L_2.,,P)WE9D&@X1"@D.4%D"?@
M!+`GX`'@CN`(L`O@`<",X`7@CN`'L"O@"L",X`ZPB^`4X)WE:*&@X0:0">#H
MS8S@!9`IX`G`C.`*D"3@#)`)X`'@CN`$D"G@!^".X`Z0B>`8X)WE[+V+X&S!
MH.'KG8G@`>".X`1`CN`,X"K@"^`.X&NQH.$*X"[@!$".X!S@G>7I383@`>".
MX`J@CN`+X"S@">`.X&F1H.$,X"[@"N".X""@G>7D[8[@`:"*X`R@BN`)P"O@
M!,`,X&1!H.$+P"S@"L",X"2@G>7NS8S@`:"*X`N@BN`$L"G@#K`+X&[AH.$)
ML"O@"K"+X"B@G>7LO8O@`:"*X`F@BN`.D"3@#)`)X&S!H.$$D"G@"I")X"R@
MG>7KG8G@`:"*X`2@BN`,0"[@"T`$X&NQH.$.0"3@"D"$X#"@G>7I383@`:"*
MX`Z@BN`+X"S@">`.X&F1H.$,X"[@"N".X#2@G>7D[8[@`:"*X`R@BN`)P"O@
M!,`,X&1!H.$+P"S@"L",X#B@G>7NS8S@`:"*X`N@BN`$L"G@#K`+X&[AH.$)
ML"O@"K"+X#R@G>7LO8O@`:"*X`F@BN`.D"3@#)`)X&S!H.$$D"G@"I")X$"@
MG>7KG8G@`:"*X`2@BN`,0"[@"T`$X&NQH.$.0"3@"D"$X$2@G>7I383@`:"*
MX`Z@BN`+X"S@">`.X&F1H.$,X"[@"N".X$B@G>7D[8[@`:"*X`R@BN`)P"O@
M!,`,X&1!H.$+P"S@"L",X$R@G>7NS8S@`:"*X`NPBN`$H"G@#J`*X&[AH.$)
MH"K@"["*X%"@G>7LO8O@`:"*X`F@BN`.D"3@#)`)X&S!H.$$D"G@"I")X%2@
MG>7KG8G@`:"*X`2@BN`,0"[@"T`$X&NQH.$.0"3@"J"$X%A`G>4!0(3@Z1V*
MX&"@G>4.0(3@"^`LX`G@#N!ID:#A#.`NX`3@CN!<0)WEX>V.X`)`A.`,P(3@
M"4`KX`%`).!A$:#A!,",X`)`BN#NK8S@`<`IX`[`+.`+0(3@#$"$X&3`G>5N
ML:#AZDV$X`O@(>`*X"[@`L",X`G`C.!JD:#A#N",X&C`G>4)H"O@Y.V.X`2@
M*N!D0:#A`L",X`$0C.!LP)WE"A"!X`2@*>`.H"K@[AV!X&[AH.$"P(S@"\",
MX`ZP).`*P(S@<*"=Y0&P*^#AS8S@81&@X0*@BN`)H(K@=)"=Y0N@BN#LK8K@
M`I")X`1`B>`!D"[@#)`IX&S!H.$)D(3@>$"=Y>J=B>`"L(3@#D"+X`S@(>`*
MX"[@:K&@X0Y`A.!\X)WE@*"=Y>E-A.`"X([@`1".X`O@+.`)X"[@:9&@X0[@
M@>`"$(K@":`KX`P0@>"$P)WEY.V.X`2@*N!D0:#A"A"!X.X=@>`$H"G@`L",
MX`Z@*N`+P(S@;N&@X0K`C."(H)WE#K`DX.'-C.`!L"O@81&@X0*@BN`)H(K@
MC)"=Y0NPBN#LO8O@`I")X`1`B>`!D"[@#)`IX&S!H.$)D(3@D$"=Y>N=B>`"
MH(3@#D"*X`S@(>`+X"[@:Z&@X9BPG>4.0(3@E."=Y>E-A.`"X([@`1".X`K@
M+.`)X"[@:9&@X0X0@>#D[8'@`A"+X`P0@>"<P)WE";`JX`2P*^!D0:#A"["!
MX`+`C.`$$"G@#A`AX`K`C.`!P(S@H!"=Y>Z]B^!NX:#AZ\V,X`Z@).`"$('@
M"Z`JX`F0@>"D$)WE:[&@X0J0B>"HH)WE[)V)X`(0@>`$$('@"T`NX`Q`).!L
MP:#A`B"*X`X@@N`,X"O@">`NX`00@>`.((+@K."=Y6E!H.'I'8'@!)",X0&0
M">#A+8+@`^".X`NPCN`$X`S@#N")X;"0G>5A$:#A"^".X+2PG>4!H(3AXNV.
MX`*@"N`#D(G@8B&@X0R0B>`!P`3@`["+X`S`BN&XH)WE!+"+X`E`C.!ND:#A
M`L"!X>Y-A.`.P`S@`N`!X`[@C.$)P(+A"^".X`3`#.`#L(K@":`"X`&PB^`*
MP(SAO!"=Y0O`C.#`L)WEY.V.X&1!H.'NS8S@!*")X0,0@>`.H`K@`B"!X&[A
MH.$$$`G@`["+X`$0BN$)L(O@Q)"=Y0(0@>`.((3A[!V!X`P@`N!LP:#A#J`$
MX`.0B>`*((+A#*".X01`B>`!H`K@#)`.X`L@@N#,L)WE":"*X>$M@N`$H(K@
MR$"=Y6$1H.'BK8K@`9",X0.PB^`#0(3@`I`)X`Y`A.!B(:#A`>`,X`[@B>$,
ML(O@!$".X`+`@>%JD:#AZDV$X`+@`>`,H`K@#N"*X="@G>4)P(+A"^".X`3`
M#.#D[8[@9$&@X0.PBN`)H`+@`;"+X`K`C.'4$)WE"\",X-BPG>4$H(GA[LV,
MX`Z@"N!NX:#A`Q"!X`(@@>`#L(O@!!`)X`FPB^#<D)WE`1"*X0Z@!.`"$('@
M#B"$X>P=@>`,(`+@;,&@X0.0B>`*((+A#*".X0&@"N`$0(G@#)`.X`L@@N#D
ML)WE"9"*X>$M@N`$0(G@X)"=Y6$1H.'B383@`:",X0.PB^`#D(G@`J`*X`Z0
MB>!B(:#A`>`,X`[@BN$"H('A">".X`2@"N!DD:#AY.V.X`)``>`,P(O@!$"*
MX0F@@N$,P(3@Z$"=Y0Z@"N#NS8S@";`"X&[AH.$+L(KA`T"$X`Z@B>$!$(3@
M[$"=Y0R@"N`!$(O@\+"=Y>P=@>!LP:#A`T"$X`(@A.`.0`G@!$"*X0.@B^`"
M0(3@#"".X>%-A.`!L`+@81&@X0P@#N`)D(K@`B"+X?2@G>4!L(SA"2""X`2P
M"^`!D`S@";"+X?B0G>7D+8+@`Z"*X&1!H.$.X(K@`S")X`Z0B^`$X('A!*`!
MX`+@#N`,P(/@"N".X=8Q#.,,P([@_."=Y6(Z3./BG8G@8B&@X0"QG>7IS8S@
M`^".X`$0CN`"X"3@">`NX&F1H.$.$('@[.V!X`01G>4#H(O@!$"*X`RQG>4)
MH"+@#*`JX&S!H.$#$('@`B"!X`P0*>`.$"'@"D"$X`$@@N`($9WE[DV$X&[A
MH.'D+8+@`Z"!X&01H.$)H(K@#I`LX`E`).`$H(K@`T"+X!2QG>4,P(3@`4`N
MX`)`).#BK8K@!$",X!#!G>5B(:#A:I&@X>I-A.`#P(S@#N",X`+`(>`*P"S@
M#,".X`/@B^`<L9WE`1".X`G@(N`$X"[@Y,V,X`X0@>`8X9WE9$&@X>P=@>`$
MH"G@#*`JX`/@CN!LP:#A`N".X`J@CN`#((O@#.`DX"2QG>4)((+@`>`NX`[@
M@N`@(9WEX:V*X&$1H.'J[8[@`Y""X&HAH.$$D(G@`4`LX`I`).`$0(G@`Y"+
MX"RQG>4,P(G@`I`AX`Z0*>#N383@"<",X"B1G>5NX:#AY,V,X`.@B>!DD:#A
M`:"*X`X0(N`$$"'@`T"+X#2QG>4"((3@"4`NX`Q`).`!$(K@!"""X#!!G>7L
M'8'@;,&@X>$M@N`,H"G@`:`JX`-`A.!A$:#A#D"$X`I`A.`#X(O@`:`LX#RQ
MG>4)X([@`J`JX.)-A.!BD:#A"B".X#CAG>7D+8+@`Z".X&3AH.$,H(K@"<`A
MX`3`+.`#0(O@1+&=Y0$0A.`.0"G@`D`DX`S`BN`$$('@0$&=Y>+-C.!B(:#A
M[!V!X`.@A.!L0:#A":"*X`*0+N`)P"S@`Y"+X$BQG>4,P(K@#N")X$RAG>4$
MD"+@X<V,X`&0*>!A$:#A`S"+X`G@CN`(,(/@`9`DX.SMCN`",(/@$""0Y0R0
M*>`)D(/@;,&'X.X]B>`.X(;@`1"%X`1`@N`(0(#H!#"=Y0C`@.4,$(#E$$"`
MY0`PD^4#`%KA!@``&E7?C>+00,WAV&#-X="!S>'8H<WA(-"-X@3PG>2J^__K
MK'$!`#@!``#P,)_E\$)MX?A@S>$`<%#B\('-X1B@C>4<X(WE`S"/X#````K0
M()_E`C"3YP"0D^4``%GC+0``"@`PU^4]4%/B`5"@$P``4^,`4*`#``!5XQ<`
M`!H`0)GE``!4XPT```H!@*#A"6"@X04@H.$'$*#A!`"@X;'[_^L``%#C`@``
M&@4PU.<]`%/C$```"@1`MN4``%3C\___&@0`H.'00,WAV&#-X="!S>$8H)WE
M'-"-X@3PG>0'4*#A`3#UY0``4^,]`%,3^___&@=01>#@___J"6!&X`%0A>)&
M8:#A!4"$X`!@B.7K___J!T"@X>G__^H)0*#AY___ZJ1E`0`T`0``]$%MX9PP
MG^4`4*#A^&#-X91PG^40X(WE#-!-X@U`H.$'<(_@`V"7YP`PEN4$,(WE!!"@
MX04`H.&P___K``!0XPX```ID,)_E`!"=Y0,PE^<`()/E`3&"X`0`D^4``%#C
M`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H$()WE`#"6Y0,`4N$$
M```:#-"-XM!`S>'88,WA$-"-X@3PG>0^^__K.`$``*!D`0`T`0``]$)MX30R
MG^4!0*#A^&#-X0!0H.'P@<WA))*?Y?BAS>$@X(WE`"#1Y1303>()D(_@`V"9
MYST`4N,!0($"!`"@X0`PEN4,,(WE^/K_ZP!PH.$($(WB!0"@X7O__^L`@%#B
M0P``"O'Z_^L'`%#A.@``*M`QG^4(@)WE`Y"9YPB!H.$`,-7E/0!3X@$`H!,`
M`%/C``"@`P``4.,%```*!0"@X0$P\.4``%/C/0!3$_O__QH%`$#@`G"'X@"@
MF>4``(?@!_O_ZP``4.,(`(KG6```"@`@F>4!$(7B"`"=Y0`PU>4``9+G/0!3
MXP``4Q,`,,#E!@``"@$@@.(!,-'D`@"@X0``4^,]`%,3`3#"Y/G__QH],*#C
M`""@X0`PP.4!,-3D``!3XP$PXN7[__\:``"@XPP@G>4`,);E`P!2X3X``!H4
MT(WBT$#-X=A@S>'0@<WAV*'-X2#0C>($\)WD`3!(X@$@U.0``%+C`2#CY?O_
M_QKM___JS#"?Y0.0F><`L)GE`*";Y0``6N,($*`#"0``"@@PH.$+(*#A````
MZ@HPH.$$$++E`:"#X@``4>/Z__\:`S"#X@,1H.&,,)_E`S"/X``@D^4``%+C
M$0``&@$@H.,!`*#A`""#Y<'Z_^L`,%#B!#"-Y1(```H*@:#A"Q"@X0@@H.')
M^O_K!#"=Y0`PB>4!((KB`!"@XP(1@^<(H(WEFO__Z@L`H.'A^O_K``!0XP`P
MH.$``(GE`0``"@J!H.'R___J``#@X[S__^JK^O_K.`$``.!C`0`T`0```&0!
M`&`QG^7T0FWA7"&?Y?A@S>$`8%#B\('-X?BAS>$#,(_@(."-Y7S03>("0)/G
M`#"4Y70PC>4"```*`##6Y0``4^,*```:=""=Y0`PE.4#`%+A0P``&GS0C>+0
M0,WAV&#-X="!S>'8H<WA(-"-X@3PG>08^O_K`'!0XO'__PKL@)_E[)"?Y>R@
MG^4(@(_@"9"/X`J@C^`'`*#AH?K_ZP``4.,H```*$U"`X@@0H.$%`*#AL/K_
MZP``4./U__\*"1"@X04`H.&K^O_K``!0X_#__PH&`*#A0?K_ZP"PH.$%`*#A
M/OK_ZP``B^`"`(#B:/K_ZP"PH.$*,*#A`&"-Y0`@X.,!$*#C!%"-Y8CZ_^L+
M$*#A"""-X@,`H.-1^O_K`0!PXPL`H.$#```*&#"=Y0\Z`^(!"5/C"```"BOZ
M_^L+`*#A#OK_Z]+__^H'`*#A0?K_ZP8`H.%:^O_KN?__ZJ?__^OU___J3?K_
MZZ!A`0`X`0``#!X```P>```,'@``E#"?Y?!!;>$`4*#AC""?Y0A@C>4,X(WE
M`S"/X`)`D^<``)3E_/G_ZTHO@.(%$*#A`P"@XUCZ_^L``%#C!```"@``H./0
M0,WA"&"=Y0S0C>($\)WD``"4Y>_Y_^LX,9#E#SH#X@$)4^,%```*``"4Y>GY
M_^LX,9#E#SH#X@H*4^/N__\:!0"@X0(0H./E^?_K$`]OX:`"H.'I___J*&`!
M`!`!``#P0FWA'$&?Y?\O`.,8,9_E^&#-X0!PH.'P@<WA#`&?Y0&`H.$8H(WE
M!$"/X!S@C>4!VDWB`Z"4YPC03>(!RHWB!&"-X@3`C.(&$*#A``"/X``PFN4`
M,(SE(_K_ZP``4.,K``#:"%"-X@&00.+`,)_E"5"%X`0@5>4#,)3G``!2XP!`
MD^4:```*`)"@X0D@H.$O$*#C!@"@X2OZ_^L``%#C%0``"@0`H.&R^?_K"3"@
MX08@H.$'$*#AS/G_ZP$ZC>($,(/B`""3Y0`PFN4#`%+A$P``&@':C>((T(WB
MT$#-X=A@S>'0@<WA&*"=Y1S0C>($\)WD``!9X^/__QH$`*#AG/G_ZP@@H.$'
M$*#AA_G_Z^G__^H8,)_E`S"4YP!`D^7U___JU?G_ZW1?`0`X`0``.!P``!`!
M```(0"WE/$"?Y3PPG^4$X(WE!$"/X`,PE.<``)/EA_G_ZR@@G^4H,)_E*!"?
MY03@G>4"()3G`S"/X`!`G>4(T(WB`1"/X.GY_^I47@$`$`$``"0!``#8&@``
M'!L``&`PG^4(0"WE7""?Y03@C>4(T$WB`S"/X`)`D^<``)3E;_G_Z][__^L`
M`)3E;/G_ZP`0H.,T,)_E-""?Y000C>4P$)_E`S"/X`(@C^``,(WE`1"/X&[Y
M_^L(T(WB`$"=Y030C>($\)WD]%T!`!`!``"H'0``Q!0``,P:``#<,)_E]$%M
MX=@@G^7X8,WA$."-Y0+:3>(<T$WB`S"/X`Q`C>("4)/G`BJ-X@%JC>(4((+B
M$&"&X@`PE>4`,(+EG_G_ZZ#`G^4!(`'C`1"@XY@PG^4,P(_@`S"/X`$0C>@$
M`*#AI?G_ZP0`H.$&$*#A`2J@XYCY_^L`0%#B%0``N@$`A.)V^?_K`'!0X@0`
M``H&$*#A!""@X4KY_^L`,*#C!##'YP(ZC>('`*#A%#"#X@`@D^4`,)7E`P!2
MX0<``!H"VHWB'-"-XM!`S>'88,WA$-"-X@3PG>0`<*#C\/__ZF+Y_^MP70$`
M.`$``'`:``!@&@``P?__ZO1";>%X,I_E`$"@X?A@S>%P`I_E`5"@X?"!S>%H
M@I_E^*'-X2#@C>4!VDWB+-!-X@``C^`(@(_@`2J-X@,PF.<D((+B*)"-X@@0
M2>(4,(WE`#"3Y0`P@N6=_?_K`&"@X2\0H.,$`*#AW_C_ZP``4.,3```*%`*?
MY000H.$``(_@`/[_ZP0`H.$!.HWB)#"#X@`@D^44,)WE`#"3Y0,`4N%V```:
M`=J-XBS0C>+00,WAV&#-X="!S>'8H<WA(-"-X@3PG>0$`*#A^OC_Z\`1G^4`
MH*#A!0"@X0$0C^`K^?_K`'!0XN+__PJH,9_EJ+&?Y0,PC^`+L(_@&#"-Y9PQ
MG^4#,(_@'#"-Y0`PU^4``%/C.P``"@``5N,$```*!Q"@X08`H.%)^?_K``!0
MXSL```H'`*#AW_C_ZP$P0.(#(-?G`S"'X"\`4N,%```:`!"@XP`0P^4!('/E
M`0!`XB\`4N/Z__\*`3"*X@``@^`!"E#CO___JBC!G^4$4$GB`2J@XP$0H.,+
M,*#A"$"-Y04`H.$,P(_@@!"-Z!KY_^L$,9_E`W"8YP``E^6P^/_K2B^`X@40
MH.$#`*#CW_C_ZP``4.,%```:``"7Y:CX_^LX,9#E#SH#X@()4^,9```*R!"?
MY0``H.,!$(_@Z/C_ZP!PH.$``%?CGO__"@`PU^4``%/CP___&@``5N,*```*
M!@"@X1@0G>4-^?_K``!0XQ0``!J($)_E``"@XP$0C^#7^/_K`'"@X>W__^H!
M`*#C''"=Y<?__^H!$*#C!0"@X8KX_^L``%#CX/__&E0`G^4%$*#A``"/X(?]
M_^L%`*#AM?C_ZX3__^H!`*#C&'"=Y;C__^J\^/_K.`$``*`9``!@7`$`8!D`
M`!09``!\&```_!@``&P8``!H&```$`$```@8``#$%P``?!<````PT.4``%/C
M!0``"@$@@.(O`%/C`@"@`0$PTN0``%/C^O__&A[_+^'P06WA`$!0X@A@C>4,
MX(WE&@``"@!0U.4``%7C%P``"FSX_^L!`$#B`""$X`(`5.$+```J`##4YR\`
M4^,P```:`3!"X@(``.H`$-+E+P!1XRL``!H$`%/A`R"@X0$P0^+X__\:`@!4
MX0L``!HO`%7C+P``"L0`G^4``(_@`0``ZKP`G^4``(_@T$#-X0A@G>4,X)WE
M$-"-XG+X_^H!($+B`P``Z@`0TN4O`%'C`P``&@,@H.$"`%3A`3!"XOC__SH$
M($+@`C""X@$*4^,``*"#!P``BFP`G^4$$*#A`2""X@$ZH.,``(_@`$"@X1CX
M_^L$`*#AT$#-X0A@G>4,T(WB!/"=Y`$P0N("``#J`!#2Y2\`4>/@__\*`P!4
MX0,@H.$!,$/B^/__.@(`5.'.__\*V?__ZA``G^4``(_@T?__ZJ`6```(%@``
ME%H!`%05``#X,9_E_$%MX?0AG^7X8,WA\,&?Y?"!S>$8X(WE--!-XN0!G^4#
M,(_@!("-X@*0D^<,P(_@U"',X0``C^#<0<SA`'"9Y;SBW.'P(<WAU"+,X?A!
MS>&T09_E+'"-Y=Q@S.$$0(_@^&#-X?`BS>&XXLWAR_S_ZY@!G^4``(_@R/S_
MZY`!G^4``(_@Q?S_ZX@!G^4``(_@POS_ZX`!G^4``(_@O_S_ZW@!G^4``(_@
MO/S_ZW`!G^4``(_@N?S_ZV@!G^4``(_@MOS_ZP0`H.&T_/_K6`&?Y0``C^"Q
M_/_K4`&?Y0``C^"N_/_K2`&?Y0``C^"K_/_K0`&?Y0``C^"H_/_K.`&?Y0@0
MH.$``(_@9/S_ZP`04.(!```*!`"@X<W\_^L<`9_E"!"@X0``C^!<_/_K`!!0
MX@(```H(`9_E``"/X,3\_^L``9_E"!"@X0``C^!3_/_K`!!0XA$```KL`)_E
M``"/X+O\_^OD$)_EY`"?Y0$0C^```(_@MOS_ZRP@G>4`,)GE`P!2X1L``!HT
MT(WBT$#-X=A@S>'0@<WA&-"-X@3PG>2P`)_E"!"@X0``C^`[_/_K`!!0X@L`
M`!J<$)_E"B"@XQD`C>(!$(_@!/C_ZP``4./C__\:A`"?Y2,0C>(``(_@F_S_
MZ][__^IT`)_E``"/X)?\_^O:___JT??_ZT!8`0`X`0``W!0``)05``"\%0``
M8!4``%P5``!<%0``6!4``%P5``#L%```4!4``%05``#,%```2!4``$@5``!$
M%0``.!4``#@5```T%0``0!0``$`5``"`%```Y!0``-P4```P%```(!0``)`0
MG^4(0"WEC""?Y03@C>4(T$WBA#"?Y0$0C^`"0)'G`S"/X```D^4`,)3E`0!P
MXP0PC>4'```*!""=Y0`PE.4#`%+A$@``&@C0C>(`0)WE!-"-X@3PG>1$`)_E
M#1"@X0``C^#S^__K``!0XP0```H``-#E,`!0XP``4!,!`*`3``"@`QPPG^4#
M,(_@``"#Y>C__^J0]__KX%4!`#@!```P5P$`1!,``,A6`0`(0"WE!."-Y3WW
M_^M@]__K``!0XP!`G>4$T(WB``"0%03PG>14,9_E]$)MX5`1G^7X8,WA`'"@
MX4@AG^7P@<WA^*'-X0,PC^`@X(WE1-!-X@$0C^`"D)/G!`"!XM1`P>'<(,'A
M'!"1Y0#@F>7P0LWA``!4X_@BS>'0(<#A\"/-X3@0C>4\X(WE&P``"OBPG^4D
M4(WB'("-XO"@G^4+L(_@"J"/X`8``.H'$*#A1/?_ZP``4.,;```*!$"5Y```
M5.,-```*"!"@X00`H.&N^__K`&!0X@(```H`,-;E``!3X_#__QH$`*#A!Q"@
MX1/\_^L$0)7D``!4X_'__QH\()WE`#"9Y0,`4N$;```:1-"-XM!`S>'88,WA
MT('-X=BAS>$@T(WB!/"=Y`<`H.$/]__K`#"@X08`H.$4,(WE"_?_ZQ0PG>4`
M`(/@`@"`XC3W_^L+,*#A`"#@XX`$C>@!$*#C"&"-Y10`C>54]__K!`"@X100
MG>7Q^__KSO__ZBOW_^L(50$`5%8!`#@!```,$@``!!(``/1";>$X.I_E^&#-
MX?"!S>$PBI_E`)"@X2P*G^7XH<WA(."-Y8'<3>(,T$WB"("/X$)/C>(#,)CG
M``"/X(%<C>($4(7B*,"0Y=AP1.+<H\#A!Q"@X0#@D^4<,(WEU"/`X<S`!.4`
MX(7E3."0Y?RJ1.'<HL#A]"M$X=`BP.'T+43AU"3`X<0)G^7X+$3A``"/X,#@
M!.7\JT3A5OO_ZP!04.("```*`##5Y0``4^,!`0`:;?__ZP!@4.(#`0`*!@"@
MX<7V_^N``*#A`0"`XN_V_^L`,-;E`*"@X0``4^,,```*;+F?Y0I0H.$+L(_@
M!0"@X0`PC>4`(.#C"S"@X0$0H.,)]__K`3#VY0)0A>(``%/C]?__&KP`%.4`
M`%#C$@``"KQ01.("``#J!`"UY0``4.,-```*!Q"@X2[[_^L`8%#B^/__"@`P
MUN4``%/C]?__"HC\_^L``%#C\O__"@8`H.'!]O_K`#!0XA<``!H`L*#CU&!$
MX@LQA.#44!/E``!5XPH```H`,-7E``!3XP<```H%`*#A`;"+XG;\_^L``%#C
M!```&@M1EN<``%7C]/__&@`PH.,$``#J!0"@X:KV_^L``%#CZO__"@`PH.$#
M`*#A(#"-Y8#V_^L`4*#A"@"@X7WV_^L`4(7@`5N%X@10A>(%`*#AI?;_ZUCH
MG^4`8*#A`"#@XU#(G^4!$*#C#*"-Y2`PG>4.X(_@#,"/X`A0C>@X.)_E`S"/
MX+_V_^L&`*#A!QV@XQWV_^L!`'#C`P``&M'V_^L`()#E$0!2X\H!`!H,.)_E
M`["8YP``F^5,]O_K2B^`X@80H.$#`*#CJ/;_ZP"@4.(9```*Z">?Y0$0H.,`
M4*#C`#"9Y0(`F.<`8(WEU">?Y0``D.4"((_@@?;_ZX$\C>(%`*#A!#"#X@`@
MD^4<,)WE`#"3Y0,`4N'?`0`:@=R-X@S0C>+00,WAV&#-X="!S>'8H<WA(-"-
MX@3PG>0``)OE*O;_ZS@QD.4/.@/B`0E3X]___QH``)OE)/;_ZT`QD.4@,(WE
M&/;_ZR`PG>4``%/AU___&@``F^4<]O_K.#&0Y5,PZ.<'#5/CT?__&@4`H.%5
M]O_K`%"@X2P'G^4'$*#A``"/X*KZ_^L``%#C=@``"@!PF>5#]O_K`!"@X0<`
MH.'N_/_K`'!0XF\```H'`*#A&/;_ZP,`4.,`@*#A#```FN@6G^4$`$#B``"'
MX`$0C^!V]O_K``!0XP4``!H$`%CC6@$`"@B`A^`%,%CE+P!3XU8!``J`_O_K
M`!!0X@0``!H'`*#A$O;_ZP`P4.(D,(WE5P``&I@6G^68!I_EF):?Y9B&G^4!
M$(_@E':?Y0``C^#L^O_K//;_ZXCFG^4(`(WE`"#@XX#&G^4!$*#C!0"@X7@V
MG^4)D(_@"("/X`=PC^`.X(_@#,"/X`,PC^!`$(WH#."-Y3OV_^L.``#J4?;_
MZP`PD.41`%/C$```&@&@BN(E]O_K!""@X0DPH.'P8,WA"`"-Y0$0H.,%`*#A
M#*"-Y1"`C>4K]O_K!QV@XP4`H.&)]?_K`0!PXP!`H.'J__\*!@"@X;?U_^OT
M!9_E!1"@X0``C^"_^O_K!0"@X7;^_^MY___J=/[_ZP4`H.'I]?_K`%"@X73_
M_^H&4*#A0*"-X@4!FN<``%#C#```"@<0H.$!4(7B0OK_ZP`P4.+W__\*`##3
MY0``4^/T__\*V?7_ZP``4./Q__\*`&"@X>G^_^J`99_E#0"@X]OU_^L`H*#A
M4S"@XP9@C^#K_O_J`'"9Y8W__^H"<*#C!!!$X@`PX.,1(.#C`8"@X0!PC>4@
M$(WERO7_ZP@0H.$&(*#C)`"=Y8?U_^L$,%3E``!3XP(``!H#,%3E0P!3XPH!
M``H`<*#C9!"-XB0`G>4`(*#C`#"@XP!PC>4H$(WEN/7_ZP'#`N.)"PKCD'`$
MY?X<#>-V)`7CC'`$Y?`Q#N-%QT;C+%"-Y<T/3N.Z&$GC,B!!X](S3..DP`3E
M\`I$X?@I1.%(<`3E`BF@XR`0G>4D`)WE9/7_ZP"04.):``#:D#`4Y8DAH.$`
M$*#C`C"3X(P@%.4!$*`C``!1XT@0%.60,`3E`2""$JDN@N```%'CC"`$Y4H`
M``I`<&'BB`!$X@<`6>$!`(#@(!"=Y0EPH+$'(*#A9_7_ZT@P%.4#,(?@0`!3
MXT@P!.7>__\:(#"=Y0>02>`H`)WE!W"#X-OV_^L_`%GC+P``VD"02>(H4)WE
M@("'XC\PR>-`H(?B"("#X`HPH.$%`*#A0!`SY4"@BN($P)/EB!`$Y0@0D^4,
ML)/E$."3Y83`!.44P)/E@!`$Y1@0D^5\L`3E'+"3Y7C@!.4@X)/E=,`$Y23`
MD^5P$`3E*!"3Y6RP!.4LL)/E:.`$Y3#@D^5DP`3E-,"3Y6`0!.4X$)/E/#"3
MY5RP!.58X`3E5,`$Y5`0!.5,,`3EK_;_ZP@`6N'9__\:*3.@X0$@@^(#DTG@
M`G.'X`<0H.%$,*#C"2"@X8@`1.(4]?_K2)`$Y:#__^H@<)WEQ/__ZB0`G>6(
MD$3B+%"=Y3#U_^N0<!3E?Q#@XXR`%.77(>7G`3""XC@`4^,"$,GG;0``R@,`
MB>`X(&/B`!"@X^7T_^LH/*#A)QR@X>B2G^4H"*#A)RB@X5`P1.4G-*#A"9"/
MX$V`1.4HA*#A3P!$Y2@`G>4(H$3B3!!$Y3`01.).@$3E1(!$XDL@1.5*,$3E
M27!$Y0%PH.$@$(WE>?;_ZZ3`%.70"D3AF+`4Y90@%.4L/*#A+.B@X3T`1.5!
MP$3E+,2@X3D01.4UL$3E1#!$Y4+`1.4@S*#A,2!$Y4/@1.5`P$3E(,B@X2`$
MH.$_P$3E(<R@X3X`1.4A"*#A(12@X3S`1.4[`$3E*PR@X3H01.4K&*#A*[2@
MX3@`1.4B#*#A-Q!$Y2(8H.$B)*#A-K!$Y30`1.4S$$3E,B!$Y0```.H!,/CE
M!P"@X0`PC>4`(.#C`1"@XP)PA^(),*#A&?7_ZP<`6N'U__\:(""=Y0`PH.,`
M8(WEQ`&?Y0$0H./`P9_E"""-Y0`@X.,(,$3EM#&?Y0``C^`,P(_@!,"-Y0P`
MC>4#,(_@!0"@X0;U_^O?_O_J!("9Y0``6..E_O\*"`"@X:ST_^L#`%#CH?[_
MFG@1G^4$`$#B``"(X`$0C^`+]?_K``!0XPAPH`&9_O_J0"!CX@,`B>``$*#C
M=_3_ZR@`G>4@]O_K"0"@X3@@H.,`$*#C<?3_ZXK__^KD`)_E`1"@XP!0H.,`
M,)GE``"8YP!@C>4$((WE%"&?Y0``D.4"((_@O_3_ZSS^_^H",%3E00!3X_'^
M_QH!,%3E0P!3X^[^_QH`,-3E2`!3X^O^_QH!,-3E10!3X^C^_QHD0)WE`##@
MXSD@X.,`<(WE!`"@X:/T_^L$`*#A($"=Y2D@H.,$$*#A7_3_ZZC@G^4`(.#C
M`1"@XZ#`G^4%`*#A"$"-Y9@PG^4.X(_@#,"/X`,PC^!`$(WH#."-Y;OT_^N4
M_O_JE?3_ZS@!``",4P$`V%0!`&@0```H$0``$!````0/``#T#P``$`$``#P!
M``#0#P``K!```"P/```<#@``=`T``-0.``"`#P``_`P``'@/``#T#```L`X`
M`%`,``#@#```3`H``*@*```D"```R`D``(@)``","```>`D``/0&``"@"```
MZ".?Y?1";>'D$Y_E^&#-X?"!S>'<,Y_E^*'-X2#@C>4<T$WB`B"/X!!@C>((
M8(WE`0"2YP`0D.4,`(WE%!"-Y0-`DN<``)3E(/3_ZP!0H.$``)3E'?3_ZV0P
MU>4&$*#A93#`Y9`#G^4``(_@L/C_ZP``4.,"```*`##0Y3$`4^.X```*`?S_
MZP``E.4/]/_K:!.?Y0LPH.,!(*#C`1"/X/+S_^L``%#C2@``"E`CG^4,$)#E
M`*"4Y0(@C^`$()+E&("1Y0$`4N-#``#:-#.?Y0&;H.,`8*#C++.?Y2"00.,!
M4*#C`S"/X`NPC^``,(WE"@``Z@P0D.4'`*#A:_3_ZP`PG>4``%#C!#"3Y1X`
M`!H!4(7B`6"&X@4`4^$:``#:"@"@X>GS_^L($*#A`#"@XP8@H.$)]/_K`!!0
MXHT```H``)'E",";Y0"@E.4(,)#E!7&<YPDP`^`!"U/CY/__"@H`H.$$$(WE
MV//_ZP00G>4",*#C`""@XP`0D>57]/_K`!"@X0"@E.7:___J`R"@X0$00N(&
M`%'A#P``&@$`4N,-``#:9&*?Y0%0H.,*`*#A!F"/X````.H``)3EP_/_ZP@0
MH.$!4(7BI?/_ZP0PEN4%`%/A]___R@"@E.4*`*#ANO/_ZR@2G^4#,*#C`2"@
MXP$0C^"=\__K`%!0X@L```H``)3EL?/_ZPPPE>4$(I_E`!"3Y0(@C^":\__K
M##"5Y0`PD^4(,)/E`043XU\``!H``)3EI?/_Z]P1G^4#,*#C`2"@XP$0C^"(
M\__K`%!0X@L```K$`9_E"!"=Y0``C^`S^/_K`&!0X@``E.5&```*EO/_ZPPP
ME>4&(*#A`!"3Y8#S_^L``)3ED//_ZP!0H.$``)3EC?/_ZX01G^4!(*#C`1"/
MX%SS_^MX(9_E`!"@X04`H.%P49_E`B"/X''S_^L``)3E!5"/X(#S_^L`,*#A
M6`&?Y0`@H.,($)WE92##Y0``C^`2^/_K``!0XP!`H.$,`(7E$@``"@<=H.,$
M`*#A.?/_ZP$P@.(1`%#C`0!3$RT``(H,,)WE%""=Y0`PD^4#`%+A)P``&AS0
MC>+00,WAV&#-X="!S>'8H<WA(-"-X@3PG>0(`)7E>_S_ZP``4.,`0*#A#`"%
MY>;__QK0`)_E``"/X*WS_^L!,-#E``!3XT3__PI"___JN""?Y0"@E.4"((_@
M!""2Y8#__^I/\__KI#"?Y0P@E>4#,(_@"#"3Y0``DN4`$)/E:OG_Z[3__^H`
M`)3E1?/_ZPPPE>4`$)/E>_/_ZYG__^J"\__K;!"?Y0`PH.$$(*#A9`"?Y0$0
MC^`($)'E``"/X``0D>6+\__KT$@!`#@!```0`0``'`8``*`'``#L20$`P$D!
M`+Q)`0#T2`$`5`8``#0&```,!@``X`,``+0%``"T!0``X$<!`%`#```4!0``
M)$<!``Q'`0#(1@$`M`0``/!!;>$`4*#A"&"-Y0S@C>6X^O_K`##0Y0!`H.$`
M`%/C!0``"@$@@.(O`%/C`D"@`0$PTN0``%/C^O__&IS[_^L``%7C``!0$P,`
M`!K00,WA"&"=Y0S0C>($\)WD`##5Y0``4^/X__\*+!"?Y00`H.$$(*#C`1"/
MX&OS_^L``%#C\?__&@4`H.'00,WA"&"=Y0S@G>40T(WBE/C_ZJ0"```4,)_E
M%,"?Y0,PC^`,,)/G``!3XP`PDQ5#\__J!$0!`"P!``#P0FWA=%"?Y?A@S>%P
M8)_E`'"@X?"!S>$!@*#A`I"@X1B@C>4%4(_@'."-Y09@C^`%8$;@H?+_ZT9A
ML.$)```*!%!%X@!`H.,!0(3B!#"UY0D@H.$($*#A!P"@X3/_+^$$`%;A]___
M&M!`S>'88,WAT('-X1B@G>4<T(WB!/"=Y)Q"`0"80@$`'O\OX0A`+>D(@+WH
M`0`"`'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@`````"X````N+@``)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4````
M`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`````!005)?4%)/1TY!344`````
M.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`
M````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````4$%2
M7T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)
M4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`````%!!4E]#3$5!3CT``#$```!365-414T``"4P,G@`````)7,E<R5S
M)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*``!P87)L`````"YP87(`````)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M`$%21U8`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].
M`````#$N,#,V````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````55-%
M4DY!344`````5$5-4$1)4@!435``+W1M<`````!,1%],24)205)97U!!5$@`
M3$E"4$%42`!,24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@```!3
M2$Q)0E]0051(``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[
M,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL
M"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D
M=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP
M+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D
M14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'
M5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!
M4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O
M<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=6
M7R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N
M9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N
M(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM
M>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`]
M(#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I
M>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@
M;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY
M("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A
M9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]
M("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*
M;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F
M<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S
M("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD
M;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F
M<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T
M.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES
M=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M
M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W
M-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N
M86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM
M>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U
M;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R
M(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D
M;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE
M+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN
M<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I
M;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN
M;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q
M=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@
M9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E
M<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D
M:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T
M(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T
M85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S
M8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A
M9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E
M=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%
M3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@
M+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI
M?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T
M:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N
M9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E
M<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F
M;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY
M("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N
M86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D
M7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I
M*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@
M*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F
M(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN
M9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B
M+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D
M9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&
M24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II
M9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI
M>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P
M;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E
M;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS
M<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD
M>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N
M86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?
M;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$
M-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R
M<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD
M8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H
M)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A
M8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]
M"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H
M+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U
M=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT
M<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S
M=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB
M(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50
M871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE
M.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ
M4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A
M=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M
M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q
M=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG
M<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U
M:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@
M<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@
M?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V
M86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@
M>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE
M=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C
M:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-
M4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N
M("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H
M(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@
M>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@
M*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@
M)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2![
M"B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.
M5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E
M<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I
M9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@
M)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H
M+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@
M)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E
M:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^
M(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[
M"FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA
M7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^
M861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!
M4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M
M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@
M7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R
M:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C
M;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I
M('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U
M<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D
M96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%2
M1U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O
M(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]]
M(#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.
M5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!
M3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@"!L@&!L+"N!P````"&L@&!L+"K#P````"*L@&!L+"O!P````#"
ML@&!L+"O/P````!DC/]_L*L(@`B/_W\!````D)#_?Z\_%("4G/]_L+"N@(R=
M_W^PJP*`.)[_?["O!("`H/]_L*\>@/2A_W^PL*J`D*+_?XS__W_`H_]_L+"H
M@!2D_W^PJ`&`B*3_?X#__W]TI?]_L+"P@'"E_W]\__]_(*C_?["PL(!`J/]_
ML+"J@(BI_W^PK0R`[*O_?["H`8"0K/]_L+"H@*RL_W^PKQ"`%*[_?U#__W_0
MN/]_L*\&@!"]_W^PL*J`J+W_?["PL(#$O?]_L+"N@$2^_W^PL+"`0+[_?P$`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````"@>``"T'0```0````$````!
M````Q@$```$````5`@```0```&X#```!````E`,``!T````N!0``#````-`6
M```-````G$P``!D```#8C@$`&P````0````:````W(X!`!P````$````!```
M`+0!``#U_O]O``4```4```#L#```!@```.P%```*````8P4```L````0````
M%0`````````#`````)`!``(``````@``%````!$````7````T!0``!$```"P
M$P``$@```"`!```3````"````/O__V\````(_O__;S`3``#___]O!````/#_
M_V]0$@``^O__;Q<`````````````````````````````````````````````
M````````````X(X!````````````W!8``-P6``#<%@``W!8``-P6``#<%@``
MW!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<
M%@``W!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6
M``#<%@``W!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<%@``W!8`
M`-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<%@``
MW!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<%@``W!8``-P6``#<
M%@``W!8``)A,````````````````````````````````````````5)$!`!!,
M``````````````````````````````````#P&0```````%21`0#_____&%``
M`"A0```P4```.%```$!0``!44````````!!0``#83````````!!.```43@``
M!%```$!-```,4````````/!/``#X3P```````&!0``!'0T,Z("A355-%($QI
M;G5X*2`W+C,N,2`R,#$X,#,R,R!;9V-C+3<M8G)A;F-H(')E=FES:6]N(#(U
M.#@Q,ET`03(```!A96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!
M%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`
M+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT
M`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>'1A8@`N05)-+F5X
M:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI
M8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````
M````````````````````````````````````````````````````"P````$`
M```"````5`$``%0!```9```````````````!`````````!,````'`````@``
M`'`!``!P`0``(```````````````!``````````A````!P````(```"0`0``
MD`$``"0```````````````0`````````.`````4````"````M`$``+0!``!,
M`P``!@`````````$````!````#0```#V__]O`@`````%````!0``[`````8`
M````````!`````0````^````"P````(```#L!0``[`4````'```'`````P``
M``0````0````1@````,````"````[`P``.P,``!C!0`````````````!````
M`````$X```#___]O`@```%`2``!0$@``X`````8``````````@````(```!;
M````_O__;P(````P$P``,!,``(`````'````!`````0`````````:@````D`
M```"````L!,``+`3```@`0``!@`````````$````"````',````)````0@``
M`-`4``#0%`````(```8````7````!`````@```!\`````0````8```#0%@``
MT!8```P```````````````0`````````=P````$````&````W!8``-P6```4
M`P`````````````$````!````((````!````!@```/`9``#P&0``K#(`````
M````````!`````````"(`````0````8```"<3```G$P```@`````````````
M``0`````````C@````$````"````I$P``*1,``"X0``````````````$````
M`````)8````!`````@```%R-``!<C0``,```````````````!`````````"A
M`````0``<((```",C0``C(T``-@````.``````````0`````````K`````$`
M```"````9(X``&2.```$```````````````$`````````+8````.`````P``
M`-B.`0#8C@``!```````````````!`````0```#"````#P````,```#<C@$`
MW(X```0```````````````0````$````S@````8````#````X(X!`.".```@
M`0``!P`````````$````"````-<````!`````P````"0`0``D```4`$`````
M````````!`````0```#<`````0````,```!0D0$`4)$``%P`````````````
M``0`````````X@````@````#````K)$!`*R1```8$``````````````$````
M`````.<````!````,`````````"LD0``0````````````````0````$```#P
M`````P``<```````````[)$``#,```````````````$``````````0````,`
B`````````````!^2`````0`````````````!````````````
